==> blender_2.79.b+dfsg0.orig.tar.xz: blender-2.79b+dfsg0.orig/release/scripts/addons/presets/operator/mesh.landscape_add/lakes_1.py <==
import bpy
op = bpy.context.active_operator

op.ant_terrain_name = 'Landscape'
op.land_material = ''
op.water_material = ''
op.texture_block = ''
op.at_cursor = True
op.smooth_mesh = True
op.tri_face = False
op.sphere_mesh = False
op.subdivision_x = 128
op.subdivision_y = 128
op.mesh_size = 2.0
op.mesh_size_x = 2.0
op.mesh_size_y = 2.0
op.random_seed = 9
op.noise_offset_x = 0.0
op.noise_offset_y = 0.0
op.noise_offset_z = 0.0
op.noise_size_x = 1.0
op.noise_size_y = 1.0
op.noise_size_z = 1.0
op.noise_size = 0.8500000238418579
op.noise_type = 'turbulence_vector'
op.basis_type = '2'
op.vl_basis_type = '0'
op.distortion = 1.0
op.hard_noise = '0'
op.noise_depth = 8
op.amplitude = 0.6000000238418579
op.frequency = 1.5
op.dimension = 1.0
op.lacunarity = 2.0
op.offset = 0.8999999761581421
op.gain = 2.0
op.marble_bias = '0'
op.marble_sharp = '0'
op.marble_shape = '0'
op.height = 0.25
op.height_invert = False
op.height_offset = 3.725290298461914e-09
op.fx_mixfactor = 0.0
op.fx_mix_mode = '0'
op.fx_type = '0'
op.fx_bias = '0'
op.fx_turb = 0.0
op.fx_depth = 0
op.fx_amplitude = 0.5
op.fx_frequency = 1.5
op.fx_size = 1.0
op.fx_loc_x = 0.0
op.fx_loc_y = 0.0
op.fx_height = 0.5
op.fx_invert = False
op.fx_offset = 0.0
op.edge_falloff = '3'
op.falloff_x = 4.0
op.falloff_y = 4.0
op.edge_level = 0.0
op.maximum = 1.0
op.minimum = -1.0
op.vert_group = ''
op.strata = 1.0
op.strata_type = '2'
op.water_plane = True
op.water_level = -0.019999997690320015
op.remove_double = False
op.show_main_settings = True
op.show_noise_settings = True
op.show_displace_settings = True
op.refresh = True
op.auto_refresh = True

==> blender_2.83.5+dfsg.orig.tar.xz: blender-2.83.5/release/scripts/addons/presets/operator/mesh.landscape_add/lakes_1.py <==
import bpy
op = bpy.context.active_operator

op.ant_terrain_name = 'Landscape'
op.land_material = ''
op.water_material = ''
op.texture_block = ''
op.at_cursor = True
op.smooth_mesh = True
op.tri_face = False
op.sphere_mesh = False
op.subdivision_x = 128
op.subdivision_y = 128
op.mesh_size = 2.0
op.mesh_size_x = 2.0
op.mesh_size_y = 2.0
op.random_seed = 9
op.noise_offset_x = 0.0
op.noise_offset_y = 0.0
op.noise_offset_z = 0.0
op.noise_size_x = 1.0
op.noise_size_y = 1.0
op.noise_size_z = 1.0
op.noise_size = 0.8500000238418579
op.noise_type = 'turbulence_vector'
op.basis_type = 'PERLIN_NEW'
op.vl_basis_type = 'BLENDER'
op.distortion = 1.0
op.hard_noise = '0'
op.noise_depth = 8
op.amplitude = 0.6000000238418579
op.frequency = 1.5
op.dimension = 1.0
op.lacunarity = 2.0
op.offset = 0.8999999761581421
op.gain = 2.0
op.marble_bias = '0'
op.marble_sharp = '0'
op.marble_shape = '0'
op.height = 0.25
op.height_invert = False
op.height_offset = 3.725290298461914e-09
op.fx_mixfactor = 0.0
op.fx_mix_mode = '0'
op.fx_type = '0'
op.fx_bias = '0'
op.fx_turb = 0.0
op.fx_depth = 0
op.fx_amplitude = 0.5
op.fx_frequency = 1.5
op.fx_size = 1.0
op.fx_loc_x = 0.0
op.fx_loc_y = 0.0
op.fx_height = 0.5
op.fx_invert = False
op.fx_offset = 0.0
op.edge_falloff = '3'
op.falloff_x = 4.0
op.falloff_y = 4.0
op.edge_level = 0.0
op.maximum = 1.0
op.minimum = -1.0
op.vert_group = ''
op.strata = 1.0
op.strata_type = '2'
op.water_plane = True
op.water_level = -0.019999997690320015
op.remove_double = False
op.show_main_settings = True
op.show_noise_settings = True
op.show_displace_settings = True
op.refresh = True
op.auto_refresh = True
